﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System.Globalization;

namespace esl
{
    class PackageManagement
    {
        public static readonly string OPT_OUT_REASON_1 = "OptOut reason One";
        public static readonly string OPT_OUT_REASON_2 = "OptOut reason Two";
        public static readonly string OPT_OUT_REASON_3 = "OptOut reason Three";

        public static readonly string OLD_LOGO_IMAGE_LINK = "old logo image link";
        public static readonly string OLD_LOGO_IMAGE_SOURCE = "old logo image source";

        public static readonly string OLD_DECLINE_REASON_1 = "old decline reason #1";
        public static readonly string OLD_DECLINE_REASON_2 = "old decline reason #2";
        public static readonly string OLD_DECLINE_REASON_3 = "old decline reason #3";

        public static readonly string OLD_HAND_OVER_LINK_HREF = "http://www.old.ca";
        public static readonly string OLD_HAND_OVER_LINK_TEXT = "old hand over link text";
        public static readonly string OLD_HAND_OVER_LINK_TOOL_TIP = "old hand over link tool tip";

        public static readonly string OLD_OPT_OUT_REASON_1 = "old opt out reason #1";
        public static readonly string OLD_OPT_OUT_REASON_2 = "old opt out reason #2";
        public static readonly string OLD_OPT_OUT_REASON_3 = "old opt out reason #3";

        public static readonly string OLD_PACKAGE_NAME = "Old Package Name";
        public static readonly string OLD_DESCRIPTION = "Old Description";
        public static readonly string OLD_EMAIL_MESSAGE = "Old Email Message";
        public static readonly DateTime OLD_EXPIRY_DATE = DateTime.Now.AddMonths(1);
        public static readonly CultureInfo OLD_LANGUAGE = CultureInfo.GetCultureInfo("en");

        // Visibility is for only template
        public static readonly Visibility OLD_VISIBILITY = Visibility.ACCOUNT;
        public static readonly bool OLD_NOTARIZED = false;

        public static readonly string NEW_LOGO_IMAGE_LINK = "new logo image link";
        public static readonly string NEW_LOGO_IMAGE_SOURCE = "new logo image source";

        public static readonly string NEW_DECLINE_REASON_1 = "new decline reason #1";
        public static readonly string NEW_DECLINE_REASON_2 = "new decline reason #2";
        public static readonly string NEW_DECLINE_REASON_3 = "new decline reason #3";

        public static readonly string NEW_HAND_OVER_LINK_HREF = "http://www.new.ca";
        public static readonly string NEW_HAND_OVER_LINK_TEXT = "new hand over link text";
        public static readonly string NEW_HAND_OVER_LINK_TOOL_TIP = "new hand over link tool tip";

        public static readonly string NEW_OPT_OUT_REASON_1 = "new opt out reason #1";
        public static readonly string NEW_OPT_OUT_REASON_2 = "new opt out reason #2";
        public static readonly string NEW_OPT_OUT_REASON_3 = "new opt out reason #3";

        public static readonly string NEW_PACKAGE_NAME = "new package name";
        public static readonly string NEW_DESCRIPTION = "new description";
        public static readonly string NEW_EMAIL_MESSAGE = "new email message";
        public static readonly DateTime NEW_EXPIRY_DATE = DateTime.Now.AddMonths(2);
        public static readonly CultureInfo NEW_LANGUAGE = CultureInfo.GetCultureInfo("fr");

        public static readonly Visibility NEW_VISIBILITY = Visibility.SENDER;
        public static readonly bool NEW_NOTARIZED = true;

        public static void main()
        {

            EslClient eslClient = new EslClient(Properties.Settings.Default.key, Properties.Settings.Default.url);

            //Retrieve package
            PackageId packageId = new PackageId("package_id_here");
            DocumentPackage retrievedPkg = eslClient.GetPackage(packageId);

            //Update package
            CeremonyLayoutSettings layoutSettingsToUpdate = CeremonyLayoutSettingsBuilder.NewCeremonyLayoutSettings()
                                .WithoutBreadCrumbs()
                                .WithoutGlobalConfirmButton()
                                .WithoutGlobalDownloadButton()
                                .WithoutGlobalNavigation()
                                .WithoutGlobalSaveAsLayoutButton()
                                .WithLogoImageLink(NEW_LOGO_IMAGE_LINK)
                                .WithLogoImageSource(NEW_LOGO_IMAGE_SOURCE)
                                .WithoutNavigator()
                                .WithoutProgressBar()
                                .WithoutSessionBar()
                                .WithoutTitle()
                    .Build();

            DocumentPackageSettings settingsToUpdate = DocumentPackageSettingsBuilder.NewDocumentPackageSettings()
                    .WithoutCaptureText()
                    .WithDecline()
                    .WithDeclineReason(NEW_DECLINE_REASON_1)
                    .WithDeclineReason(NEW_DECLINE_REASON_2)
                    .WithDeclineReason(NEW_DECLINE_REASON_3)
                    .WithoutDialogOnComplete()
                    .WithoutDocumentToolbarDownloadButton()
                    .WithHandOverLinkHref(NEW_HAND_OVER_LINK_HREF)
                    .WithHandOverLinkText(NEW_HAND_OVER_LINK_TEXT)
                    .WithHandOverLinkTooltip(NEW_HAND_OVER_LINK_TOOL_TIP)
                    .WithoutInPerson()
                    .WithoutOptOut()
                    .WithOptOutReason(NEW_OPT_OUT_REASON_1)
                    .WithOptOutReason(NEW_OPT_OUT_REASON_2)
                    .WithOptOutReason(NEW_OPT_OUT_REASON_3)
                    .WithoutWatermark()
                    .WithCeremonyLayoutSettings(layoutSettingsToUpdate)
                    .Build();

            DocumentPackage packageToUpdate = PackageBuilder.NewPackageNamed(NEW_PACKAGE_NAME)
                                .WithEmailMessage(NEW_EMAIL_MESSAGE)
                                .ExpiresOn(NEW_EXPIRY_DATE)
                                .WithLanguage(NEW_LANGUAGE)
                                .WithVisibility(NEW_VISIBILITY)
                                .WithNotarized(NEW_NOTARIZED)
                                .WithoutAutomaticCompletion()
                                .WithSettings(settingsToUpdate)
                                .Build();

            eslClient.UpdatePackage(packageId, packageToUpdate);

            //Delete package
            eslClient.PackageService.DeletePackage(packageId);
        }
    }
}
